@@ -144,7 +144,7 @@ def short_string(value):
     """
     if not isinstance(value, basestring):
         raise ValueError("str or unicode type required, received %s:%r" %
-                         type(value), value)
+                         (type(value), value))
     if isinstance(value, unicode):
         value = value.encode('utf-8')
     return struct.pack('B', len(value)) + value
@@ -194,7 +194,7 @@ def field_table(value):
         return struct.pack('>I', 0)
 
     if not isinstance(value, dict):
-        raise ValueError("dict type required, got %s", type(value))
+        raise ValueError("dict type required, got %s" % type(value))
 
     # Iterate through all of the keys and encode the data into a table
     data = list()
@@ -205,7 +205,7 @@ def field_table(value):
         try:
             data.append(encode_table_value(value[key]))
         except ValueError as err:
-            raise ValueError("%s error: %s", key, err)
+            raise ValueError("%s error: %s" % (key, err))
 
     # Join all of the data together as a string
     output = ''.join(data)
@@ -259,7 +259,7 @@ def encode_table_value(value):
     elif value is None:
         result = 'V'
     else:
-        raise ValueError("Unknown type: %s (%r)", type(value), value)
+        raise ValueError("Unknown type: %s (%r)" % (type(value), value))
 
     # Return the encoded value
     return result
@@ -296,4 +296,4 @@ def by_type(value, data_type):
     elif data_type == 'void':
         return None
     else:
-        raise ValueError("Unknown type: %s", value)
+        raise ValueError("Unknown type: %s" % value)
